## Acknowledgements

Imitation Learning: [<b>RoboMimic</b>](https://robomimic.github.io/docs/introduction/overview.html)
```
@article{mandlekar2021matters,
  title={What matters in learning from offline human demonstrations for robot manipulation},
  author={Mandlekar, Ajay and Xu, Danfei and Wong, Josiah and Nasiriany, Soroush and Wang, Chen and Kulkarni, Rohun and Fei-Fei, Li and Savarese, Silvio and Zhu, Yuke and Martín-Martín, Roberto},
  journal={arXiv preprint arXiv:2108.03298},
  year={2021}
}
```

Oculus teleop policy and transformations: [<b>DROID</b>](https://github.com/AlexanderKhazatsky/R2D2/tree/main)

<!-- ```
Website: SIRIUS
```
@inproceedings{liu2022robot,
    title = {Robot Learning on the Job: Human-in-the-Loop Autonomy and Learning During Deployment},
    author = {Huihan Liu and Soroush Nasiriany and Lance Zhang and Zhiyao Bao and Yuke Zhu},
    booktitle = {Robotics: Science and Systems (RSS)},
    year = {2023}
}
``` -->